@@ -20,6 +20,8 @@ import gtk
 import pango
 from ConfigParser import ConfigParser
 
+from debug import log
+
 PREFS = {
     "card_index": 0,
     "control": "Master",
@@ -33,7 +35,7 @@ PREFS = {
     "show_tooltip": 1,
     "toggle": "mute",
     "keys": 0,
-    "keys_backend": "hal",
+    "keys_backend": "xlib",
     "show_notify": 0,
     "notify_timeout": 2.0,
     "notify_position": 0,
@@ -97,26 +99,34 @@ class Preferences:
     def close(self, widget=None):
         """ Close preferences window """
         global _PREFERENCES
+        self._set_body()
+        self.write_file()
+        if _PREFERENCES is not None:
+            _PREFERENCES.window.destroy()
+            del _PREFERENCES
+            _PREFERENCES = None
+
+    def _set_body(self):
+        """ Set notification body """
         start, end = self.notify_body_text.get_buffer().get_bounds()
         body = self.notify_body_text.get_buffer().get_text(start, end)
         PREFS["notify_body"] = body
         self.main.notify_body = body
 
-        self.write_file()
-        if _PREFERENCES is not None:
-            _PREFERENCES.window.destroy()
-            _PREFERENCES = None
-
     def set_section(self):
         """ Set section name """
         self.section = "card-%s" % PREFS["card_index"]
 
     def init_builder(self):
         """ Initialize gtk.Builder """
-        self.glade = os.path.join(self.main.config.res_dir, "preferences.glade")
-        self.tree = gtk.Builder()
-        self.tree.set_translation_domain(self.main.config.app_name)
-        self.tree.add_from_file(self.glade)
+        try:
+            glade_file = os.path.join(
+                    self.main.config.res_dir, "preferences.glade")
+            self.tree = gtk.Builder()
+            self.tree.set_translation_domain(self.main.config.app_name)
+            self.tree.add_from_file(glade_file)
+        except Exception, err:
+            log.Warn(str(err))
 
         self.version_label = self.tree.get_object("version_label")
         self.version_label.set_text("%s %s" % (
@@ -327,7 +337,7 @@ class Preferences:
             return None
 
     def custom_mixer_filter(self, filter_info=None, data=None):
-        """ Custom filter with names of common mixer apps """
+        """ Custom file filter with names of common mixer apps """
         mixers = ["aumix", "alsamixer", "alsamixergui", "gamix",
                 "gmixer", "gnome-alsamixer", "gnome-volume-control"]
         if filter_info[2] in mixers:
@@ -369,7 +379,10 @@ class Preferences:
             model.set(iter, 2, pango.WEIGHT_BOLD)
 
             PREFS["control"] = model.get_value(iter, 1)
+            self.main.control = PREFS["control"]
             self.main.update()
+            self.main.menu.toggle_mute.set_active(
+                    self.main.alsactrl.is_muted())
             self.write_file()
 
     def on_theme_combobox_changed(self, widget=None):
